@@ -50,8 +50,8 @@ class ElastalertWebhook(WebhookBase):
             createTime = createTime,
             attributes = attributes,
             environment = environment,
-            type = "ElastAlertNotification",
-            rawData = rawData
+            type = 'ElastAlertNotification',
+            raw_data = json.dumps(payload)
         #     environment=payload.get('environment', environment),
         #     severity=payload.get('severity', severity),
         #     service=['fail2ban'],
